@@ -20,6 +20,22 @@ class UsersMixin:
         else:
             return "Unknown"
 
+    def authenticate_otp(self, seed, otp_code):
+        data = {
+            'seed': seed,
+            'otp_code': otp_code
+        }
+
+        try:
+            resp = self.http.post('user-otp-auth', data=data, use_auth=False)
+        except (ResponseError, RequestError):
+            return False
+
+        if resp.status_code == 200:
+            return True
+        else:
+            return False
+
     def authenticate(self, username, password="", public_key="",
                      remote_addr="", login_type='T'):
         data = {
@@ -37,9 +53,13 @@ class UsersMixin:
         if resp.status_code == 200:
             user = User.from_json(resp.json()["user"])
             token = resp.json()["token"]
-            return user, token
+            return {'user': user, 'token': token}
+        elif resp.status_code == 300:
+            user = User.from_json(resp.json()["user"])
+            seed = resp.json()["seed"]
+            return {'user': user, 'seed': seed}
         else:
-            return None, None
+            return dict()
 
     def check_user_cookie(self, session_id, csrf_token):
         try:
